Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8698)

Unified Diff: components/password_manager/core/browser/credential_manager_password_form_manager.h

Issue 1960653002: Fix blacklisting password forms with Credential Manager API. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2704
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/credential_manager_password_form_manager.h
diff --git a/components/password_manager/core/browser/credential_manager_password_form_manager.h b/components/password_manager/core/browser/credential_manager_password_form_manager.h
index db7b419f796812e1069e0127693ff418931c596f..7e979efd0b9cbc60c8df145733afcb64a055c228 100644
--- a/components/password_manager/core/browser/credential_manager_password_form_manager.h
+++ b/components/password_manager/core/browser/credential_manager_password_form_manager.h
@@ -33,14 +33,15 @@ class CredentialManagerPasswordFormManager : public PasswordFormManager {
public:
// Given a |client| and an |observed_form|, kick off the process of fetching
// matching logins from the password store; if |observed_form| doesn't map to
// a blacklisted origin, provisionally save it. Once saved, let the delegate
// know that it's safe to poke at the UI.
//
// This class does not take ownership of |delegate|.
CredentialManagerPasswordFormManager(
PasswordManagerClient* client,
base::WeakPtr<PasswordManagerDriver> driver,
const autofill::PasswordForm& observed_form,
+ std::unique_ptr<autofill::PasswordForm> saved_form,
CredentialManagerPasswordFormManagerDelegate* delegate);
~CredentialManagerPasswordFormManager() override;
@@ -49,6 +50,7 @@ class CredentialManagerPasswordFormManager : public PasswordFormManager {
private:
CredentialManagerPasswordFormManagerDelegate* delegate_;
+ std::unique_ptr<autofill::PasswordForm> saved_form_;
DISALLOW_COPY_AND_ASSIGN(CredentialManagerPasswordFormManager);
};
@@ -33,14 +33,15 @@ class CredentialManagerPasswordFormManager : public PasswordFormManager {
// Given a |client| and an |observed_form|, kick off the process of fetching
// matching logins from the password store; if |observed_form| doesn't map to
- // a blacklisted origin, provisionally save it. Once saved, let the delegate
- // know that it's safe to poke at the UI.
+ // a blacklisted origin, provisionally save |saved_form|. Once saved, let the
+ // delegate know that it's safe to poke at the UI.
//
// This class does not take ownership of |delegate|.

Powered by Google App Engine
This is Rietveld 408576698